.. tensorly documentation

TensorLy: Tensor Learning in Python
======================================

.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   user_guide/index
   modules/api
   auto_examples/index
   development_guide/index
   Notebooks <https://github.com/JeanKossaifi/tensorly-notebooks>
   authors


.. only:: html


   .. raw:: html

         <div class="tile is-ancestor">
              <div class="tile is-parent">
              <a class="tile is-child box" href="installation.html">
                  <p class="title">Install TensorLy</p>
                  <p class="subtitle">Installation instructions </p>
              </a>
              </div>

              <div class="tile is-parent">
              <a class="tile is-child box" href="user_guide/index.html">
                  <p class="title">User Guide</p>
                  <p class="subtitle">A friendly guide to tensor learning</p>
              </a>
              </div>

              <div class="tile is-parent">
              <a class="tile is-child box" href="auto_examples/index.html">
                  <p class="title">Examples</p>
                  <p class="subtitle">See usage examples with code</p>
              </a>
              </div>
         </div>
         
         <div class="tile is-ancestor">
              <div class="tile is-parent">
              <a class="tile is-child box" href="modules/api.html">
                  <p class="title">
                      <i class="fa fa-book" aria-hidden="true"></i>
                      API
                  </p>
                  <p class="subtitle">Functions and classes documentation</p>
              </a>
              </div>

              <div class="tile is-parent">
              <a class="tile is-child box" href="authors.html">
                  <p class="title">Authors</p>
                  <p class="subtitle">About the developers</p>
              </a>
              </div>

              <div class="tile is-parent">
              <a class="tile is-child box" href="development_guide/index.html">
                  <p class="title">
                      <span>Development guide</span>
                  </p>
                  <p class="subtitle">Contribute to the project</p>
              </a>
              </div>
         </div>



   .. raw:: html

		<script type="text/javascript">
		function disp(s) {
			 var win;
			 var doc;    
			 win = window.open("", "WINDOWID");
			 doc = win.document;
			 doc.open("text/plain");
			 doc.write("<pre>" + s + "</pre>");
			 doc.close();
			 }                   
		</script>                   
												  
											 
		<script>                
		function toggle_modal(id){
			 var modal = document.getElementById(id);
			 modal.classList.toggle('is-active');
		};
		</script>     


		<div class="modal" id="tensorly_bibtex">
			<div class="modal-background" onclick="javascrip:toggle_modal('tensorly_bibtex');"></div>
			<div class="modal-content">
				<div class="box">
				<div class="content">
				<code class="language-latex" data-lang="latex">
				   @article{tensorly, <br/>
					&nbsp;&nbsp;&nbsp;&nbsp;author = {Jean Kossaifi and Yannis Panagakis and Anima Anandkumar and Maja Pantic}, <br/>
					&nbsp;&nbsp;&nbsp;&nbsp;title = {TensorLy: Tensor Learning in Python}, <br/>
					&nbsp;&nbsp;&nbsp;&nbsp;journal = {CoRR} <br/>
               &nbsp;&nbsp;&nbsp;&nbsp;volume = {abs/1610.09555},
					&nbsp;&nbsp;&nbsp;&nbsp;year = {2018}, <br/>
					} <br/>
				</code>
				</div>
				</div>                                              
			</div>
			<button class="modal-close" onclick="javascrip:toggle_modal('tensorly_bibtex');"></button>
	  </div>



      <br/> <br/>

		<div class="card">
			<header class="card-header">
				 <p class="card-header-title">
				 If you use TensorLy, please cite:
				 </p>

				<a class="card-header-icon" onclick="javascrip:toggle_modal('tensorly_bibtex');" >
					<span class="icon" style="margin-right:0.7em">
					[bibtex]
					</span>
				 </a>
			</header>

			<div class="card-content">
			Jean Kossaifi, Yannis Panagakis, Anima Anandkumar and Maja Pantic, <strong> TensorLy: Tensor Learning in Python</strong>, <br/><a href="https://arxiv.org/abs/1610.09555">https://arxiv.org/abs/1610.09555</a>.
			</div>

	  </div>


